# Midori

## Description

Midori is an orchestrator that allows researchers to run software engineering experiments on remote clusters. It is designed to be automated for time-consuming experiments that require a large number of runs.

## Development

1. Install [poetry](https://python-poetry.org/docs/#installation).
2. Navigate to the root of the project and run `poetry install`.
3. Run `poetry run pre-commit install` to install pre-commit hooks.
4. Develop on `dev` branch and create a pull request to `dev` branch.
